@@ -20,10 +20,10 @@
 #ifndef GTR_DEFINES
 #define GTR_DEFINES 1
 
-#define BUILD_STRING	"1.0 -- 2003-09-02 09:18:50"
-#define BUILD_VERSIONS	"2.2.2 / 2.2.2 / 2.2.2 / 2.5.10"
-#define SCHEMESDIR	"/usr/share/gtranslator/colorschemes"
-#define SCRIPTSDIR	"/usr/share/gtranslator/scripts"
-#define WINDOW_ICON	"/usr/share/pixmaps/gtranslator.png"
+#define BUILD_STRING	"1.0.1 -- 2004-01-28 20:01:15"
+#define BUILD_VERSIONS	"2.3.2 / 2.3.2 / 2.5.2 / 2.6.4"
+#define SCHEMESDIR	"/usr/local/share/gtranslator/colorschemes"
+#define SCRIPTSDIR	"/usr/local/share/gtranslator/scripts"
+#define WINDOW_ICON	"/usr/local/share/pixmaps/gtranslator.png"
 
 #endif
