@@ -152,32 +152,15 @@ void gtranslator_create_main_window(void)
 	 * Create all the panes we're using later on.
 	 */
 	content_pane=gtk_vpaned_new();
-	table_pane=gtk_hpaned_new();
 	
-
 	if(GtrPreferences.show_messages_table)
 	{
 		gtranslator_messages_table=gtranslator_messages_table_new();
-	}
-	else
-	{
-		/*
-		 * Foo, foo, woo, foo -- really not the right way to do this.
-		 */
-		gtranslator_messages_table=gtk_label_new("");
-	}
-
-	if(GtrPreferences.show_messages_table)
-	{
 		table_pane_position=gtranslator_config_get_int(
 			"interface/table_pane_position");
-
+		table_pane=gtk_hpaned_new();
 		gtk_paned_set_position(GTK_PANED(table_pane), table_pane_position);
 	}
-	else
-	{
-		gtk_paned_set_position(GTK_PANED(table_pane), -1);
-	}
 	
 	extra_content_view=g_new0(GtrExtraContentArea, 1);
 	
@@ -228,13 +211,19 @@ void gtranslator_create_main_window(void)
 			TRUE, FALSE);
 	gtk_paned_pack2(GTK_PANED(content_pane), vertical_box, FALSE, TRUE);
 
-	messages_table_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
-	gtk_container_add(GTK_CONTAINER(messages_table_scrolled_window), gtranslator_messages_table);
-	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(messages_table_scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_paned_pack1(GTK_PANED(table_pane), messages_table_scrolled_window, FALSE, TRUE);
-	gtk_paned_pack2(GTK_PANED(table_pane), content_pane, FALSE, TRUE);
+	if(GtrPreferences.show_messages_table)
+	{
+		messages_table_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
+		gtk_container_add(GTK_CONTAINER(messages_table_scrolled_window), gtranslator_messages_table);
+		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(messages_table_scrolled_window), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		
+		gtk_paned_pack1(GTK_PANED(table_pane), messages_table_scrolled_window, FALSE, TRUE);
+		gtk_paned_pack2(GTK_PANED(table_pane), content_pane, FALSE, TRUE);
 	
-	gnome_app_set_contents(GNOME_APP(gtranslator_application), table_pane);
+		gnome_app_set_contents(GNOME_APP(gtranslator_application), table_pane);
+	} else {
+		gnome_app_set_contents(GNOME_APP(gtranslator_application), content_pane);
+	}
 
 	original_text_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
 	gtk_box_pack_start(GTK_BOX(vertical_box), original_text_scrolled_window, TRUE, TRUE, 0);
@@ -377,15 +366,18 @@ void gtranslator_quit(GtkWidget  * widget, GdkEventAny  * e,
 
 	gtranslator_file_close(NULL, NULL);
 
-	/*
-	 * Get the EPaned's position offset.
-	 */
-	table_pane_position=gtk_paned_get_position(GTK_PANED(table_pane));
+	if(GtrPreferences.show_messages_table)
+	{
+		/*
+		 * Get the EPaned's position offset.
+		 */
+		table_pane_position=gtk_paned_get_position(GTK_PANED(table_pane));
+		/*
+		 * Store the pane position in the preferences.
+		 */
+		gtranslator_config_set_int("interface/table_pane_position", table_pane_position);
+	}
 	
-	/*
-	 * Store the pane position in the preferences.
-	 */
-	gtranslator_config_set_int("interface/table_pane_position", table_pane_position);
 	gtranslator_utils_save_geometry();
 
 	/*
@@ -498,7 +490,7 @@ void gtranslator_application_bar_update(gint pos)
 	{
 		if(po->fuzzy>0)
 		{
-			status=g_strdup_printf(_("%s [ %i Fuzzy left ]"), _("Fuzzy"), po->fuzzy);
+			status=g_strdup_printf(ngettext("%s [ %i Fuzzy left ]", "%s [ %i Fuzzy left ]", po->fuzzy), _("Fuzzy"), po->fuzzy);
 		}	
 		else
 		{
@@ -521,7 +513,7 @@ void gtranslator_application_bar_update(gint pos)
 		{
 			gint missya;
 			missya = po->length - po->translated;
-			status=g_strdup_printf(_("%s [ %i Untranslated left ]"), _("Untranslated"), missya);
+			status=g_strdup_printf(ngettext("%s [ %i Untranslated left ]", "%s [ %i Untranslated left ]", missya), _("Untranslated"), missya);
 		} else {
 			status=g_strdup_printf(_("%s [ No untranslated left ]"), _("Untranslated"));
 			
@@ -572,19 +564,97 @@ void gtranslator_application_bar_update(gint pos)
  */
 void gtranslator_clipboard_cut(GtkWidget  * widget, gpointer useless)
 {
-	gtk_editable_cut_clipboard(GTK_EDITABLE(trans_box));
+	GtkTextBuffer* buffer = NULL;
+
+	/* We're only cutting from the translation box */
+	if (gtk_widget_is_focus(GTK_WIDGET(trans_box)) == FALSE)
+		return;
+
+	buffer = gtk_text_view_get_buffer(trans_box);
+	g_return_if_fail(buffer != NULL);
+
+	/* FIXME: revert dots */
+	gtk_text_buffer_cut_clipboard(buffer,
+				      gtk_clipboard_get(GDK_NONE),
+				      TRUE);
+	
+	gtk_text_view_scroll_mark_onscreen(trans_box,
+					   gtk_text_buffer_get_mark(buffer,
+								    "insert"));
 }
 
 void gtranslator_clipboard_copy(GtkWidget  * widget, gpointer useless)
 {
-	gtk_editable_copy_clipboard(GTK_EDITABLE(trans_box));
+	GtkTextView* focused_box = NULL;
+	GtkTextBuffer* buffer = NULL;
+	
+	if (gtk_widget_is_focus(GTK_WIDGET(text_box)))
+		focused_box = text_box;
+	
+	if (gtk_widget_is_focus(GTK_WIDGET(trans_box)))
+		focused_box = trans_box;
+	
+	g_return_if_fail(focused_box != NULL);
+	
+	buffer = gtk_text_view_get_buffer(focused_box);
+	g_return_if_fail(buffer != NULL);
+	
+	/* FIXME: revert dots */
+	gtk_text_buffer_copy_clipboard(buffer, gtk_clipboard_get(GDK_NONE));
+  	
+	gtk_text_view_scroll_mark_onscreen(focused_box,
+					   gtk_text_buffer_get_mark(buffer,
+								    "insert"));
 }
 
 void gtranslator_clipboard_paste(GtkWidget  * widget, gpointer useless)
 {
-	gtk_editable_paste_clipboard(GTK_EDITABLE(trans_box));
+	GtkTextBuffer* buffer = NULL;
+
+	/* We're only pasting into the translation box */
+	if (gtk_widget_is_focus(GTK_WIDGET(trans_box)) == FALSE)
+		return;
+
+	buffer = gtk_text_view_get_buffer(trans_box);
+	g_return_if_fail (buffer != NULL);
+
+	/* FIXME: revert dots */
+	gtk_text_buffer_paste_clipboard(buffer,
+					gtk_clipboard_get(GDK_NONE),
+					NULL, TRUE);
+  	
+	gtk_text_view_scroll_mark_onscreen(trans_box,
+					   gtk_text_buffer_get_mark(buffer,
+								    "insert"));
 }
 
+void
+gtranslator_selection_set(GtkTextView *text_view, gint start, gint end)
+{
+	GtkTextBuffer *buffer;
+	GtkTextIter start_iter;
+	GtkTextIter end_iter;
+
+	g_return_if_fail(text_view != NULL);
+	g_return_if_fail(start >= 0);
+	g_return_if_fail((end > start) || (end < 0));
+	
+	buffer = GTK_TEXT_BUFFER(gtk_text_view_get_buffer(text_view));
+	g_return_if_fail(buffer != NULL);	
+
+	gtk_text_buffer_get_iter_at_offset (buffer, &start_iter, start);
+
+	if (end < 0)
+		gtk_text_buffer_get_end_iter(buffer, &end_iter);
+	else
+		gtk_text_buffer_get_iter_at_offset(buffer, &end_iter, end);
+	
+	gtk_text_buffer_place_cursor(buffer, &end_iter);
+
+	gtk_text_buffer_move_mark_by_name(buffer, "selection_bound", &start_iter);
+}
+
+
 void gtranslator_selection_clear(GtkWidget  * widget, gpointer useless)
 {
 	GtkTextBuffer *buffer = GTK_TEXT_BUFFER(gtk_text_view_get_buffer(trans_box));
