@@ -324,7 +324,11 @@ gboolean gtranslator_parse_core(GtrPo *po)
 			 */
 			line = g_convert(rawline, strlen(rawline), "utf-8", po->header->charset, NULL, NULL, &errv);
 			if(!line) {
-				g_warning("%s:%d: could not convert line from '%s' to UTF-8: %s", po->filename, lines, po->header->charset, errv->message);
+				if (errv == NULL) {
+					g_warning("%s:%d: could not convert line from '%s' to UTF-8: %s", po->filename, lines, po->header->charset, errv->message);
+				} else {
+					g_warning("%s:%d: could not convert line from '%s' to UTF-8: [NULL ERRV]", po->filename, lines, po->header->charset);
+				}
 				continue;
 			}
 		}
@@ -637,16 +641,16 @@ void gtranslator_parse_main(const gchar *filename)
 		gtranslator_actions_enable(ACT_REMOVE_ALL_TRANSLATIONS);
 	}
 
+	/*
+	 * Fix b.g.o #120596 and #129842 via checking for our table to
+	 * be present.
+	 */
+	if(GtrPreferences.show_messages_table && !po->table_already_created)
+	{
+		gtranslator_messages_table_create();
+	}
 	if(po->header)
 	{
-		/*
-		 * Fix b.g.o #120596 via checking for our table to be present.
-		 */
-		if(GtrPreferences.show_messages_table && !po->table_already_created)
-		{
-			gtranslator_messages_table_create();
-		}
-
 		/*
 		 * If we've got still some default values,
 		 * substitute with values from preferences,
@@ -1031,7 +1035,7 @@ Your file should likely be named '%s.po'."),
 			GTK_DIALOG_DESTROY_WITH_PARENT,
 			GTK_MESSAGE_WARNING,
 			GTK_BUTTONS_OK,
-			_("File %s\ncontains %d fuzzy messages"),
+			ngettext("File %s\ncontains %d fuzzy message", "File %s\ncontains %d fuzzy messages", po->fuzzy),
 			po->filename, po->fuzzy);
 		gtk_dialog_run(GTK_DIALOG(dialog));
 		gtk_widget_destroy(dialog);
@@ -1141,8 +1145,11 @@ void gtranslator_file_close(GtkWidget * widget, gpointer useless)
 	/*
 	 * Remove the source tag and set the source tag to '1'.
 	 */
-	g_source_remove(autosave_source_tag);
-	autosave_source_tag=1;
+	if(autosave_source_tag > 1)
+	{
+		g_source_remove(autosave_source_tag);
+		autosave_source_tag=1;
+	}
 
 	/*
 	 * "Remove" the stored "runtime/filename" key.
